#!/bin/sh
#
# Archive Post Actions for the Shareware version
#

set -x

# Copy the app from the archive wrapper to the source root folder
${CP} -pR "$ARCHIVE_PRODUCTS_PATH/$INSTALL_PATH/$WRAPPER_NAME" "$SRCROOT"

# Optional, disk cleanup, remove the archive
rm -rf "${ARCHIVE_PATH}"

# get version suffix
# The defaults command can read/write to any plist file,
# just give it a path minus the .plist extension
MARKETING_VERSION=_$(defaults read "$SRCROOT/"GIFted/Info CFBundleShortVersionString)

# remove any old zip file
if [ -e "$PRODUCT_MODULE_NAME$MARKETING_VERSION.zip" ] ; then
rm -f "$PRODUCT_MODULE_NAME$MARKETING_VERSION.zip"
fi

# codesign --deep for everything, including frameworks and binaries
codesign --force --sign "Developer ID Application: Bitfield AB (29UX6T265T)" --deep "$SRCROOT/$PRODUCT_NAME.app"

# zip the app bundle using ditto
ditto -ck --keepParent "$SRCROOT/$PRODUCT_NAME.app" "$SRCROOT/$PRODUCT_MODULE_NAME$MARKETING_VERSION.zip"

# remove the app we just zipped
rm -rf "$SRCROOT/$PRODUCT_NAME.app"

# make a directory sparkle dsa signatures
SIGNATURES_DIRECTORY="$SRCROOT/Signatures"
if [ ! -d "$SIGNATURES_DIRECTORY" ] ; then
    mkdir "$SIGNATURES_DIRECTORY"
fi

# generate a key for sparkle and save to file
SAVEDDSAPATH="$SIGNATURES_DIRECTORY/$PRODUCT_NAME$MARKETING_VERSION.dsa.txt"
/Users/jogga/Developer/Sparkle/bin/sign_update "$SRCROOT/$PRODUCT_MODULE_NAME$MARKETING_VERSION.zip" /Users/jogga/Developer/Sparkle/dsa_priv.pem > $SAVEDDSAPATH

echo "Done!"
